/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.sourceforge.xradar.dynamics.XRadarDynamics;

/**
 * <p>Main to run XRadar as a command line tools (for the bravier men of all !)</p>
 *
 *  @author Romain PELISSE <belaran@gmail.com>
 *  @author Zahir Nuckchady, zahir.nu@gmail.com
 */
public class XRadarExecute {

	private static final String STATIC = "static";
	private static final String DYNAMIC = "dynamic";
	
	/**
	 * <p>Main method to run XRadar.</p>
	 * @param args
	 * @throws XRadarException
	 */
	public static void main(String[] args) throws XRadarException {
		List<String> arguments = Arrays.asList(args);
		List<String> argumentsWithoutParams = new ArrayList<String>(arguments);
		if( ! (arguments.contains(STATIC) || arguments.contains(DYNAMIC))){
			throw new IllegalArgumentException("Specify if reports are either '" + STATIC + "' or '" + DYNAMIC + "'.");
		}
		if( (arguments.contains(STATIC) && arguments.contains(DYNAMIC))){
			throw new IllegalArgumentException("Reports should be either '" + STATIC + "' or '" + DYNAMIC + "', not both at the same time.");
		}
		for(String argument :arguments){
			if ( argument.contains(STATIC) ) {
				//Removing keyword static from the arguments passed in the command line
				argumentsWithoutParams.remove(STATIC);
				//Converting the linked list into a String Array 
				String[] newArgs = new String[argumentsWithoutParams.size()];
				argumentsWithoutParams.toArray(newArgs);
				//newArgs is sent as a String Array
				XRadarStaticsCmdLine.runXRadarStatics(newArgs);
			}
			else if (argument.contains(DYNAMIC)){
				//Removing keyword dynamic from the arguments passed in the command line
				argumentsWithoutParams.remove(DYNAMIC);
				//Converting the linked list into a String Array
				String[] newArgs = new String[argumentsWithoutParams.size()];
				argumentsWithoutParams.toArray(newArgs);
				//newArgs is sent as a String Array
				XRadarDynamics.runDynamics(newArgs);
				break;
			}
		}
	}
}
