/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.ant;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;

import org.apache.tools.ant.BuildException;
import org.sourceforge.xradar.resolver.XRadarStreamHandlerFactory;

/**
 * 
 * @author Romain PELISSE, belaran@gmail.com
 *
 */
public class RadarLoaderTask extends AbstractXRadarAntTask {

	private String resource;
	private String target;

	/**
	 * @return the resourceName
	 */
	public String getResource() {
		return resource;
	}

	/**
	 * @param resource the resourceName to set
	 */
	public void setResource(String resource) {
		this.resource = resource;
	}

	@Override
	public void execute() throws BuildException {
		// Registering the new resolver to handle xradar protocol
		registerURLResolver();
		URL resourceURL = validate();
		// Extracting the resource from the URL provided
		extracting(resourceURL);
	}

	private void extracting(URL resourceURL) {
		LoaderHelper helper = new LoaderHelper(super.isOnline());
		try {
			helper.extractFrom(resourceURL.openStream(), new FileOutputStream(new File(target)));
		} catch (FileNotFoundException e) {
			throw new BuildException(e);
		} catch (IOException e) {
			throw new BuildException(e);
		} catch (Exception e) {
			throw new BuildException(e);
		}
	}

	private void registerURLResolver() {
		// FIXME: This exception catching is ugly !!!!!!
		// FIXME: Should be moved inside AbstractProcess

		try
		{
			// Adding to JVM our own URL resolver to resolve
			// the 'xradar' protocol in stylesheet
			URL.setURLStreamHandlerFactory(new XRadarStreamHandlerFactory());
		}
		catch ( java.lang.Error e)
		{
			//FIXME: this so ugly, it actually requires an other fixme !
			// Only if we run into this error we should not take care of the exception
			if ( ! "class java.lang.Error".equals(e.getClass()) &&
				 ! "factory already defined".equals(e.getMessage())	)
			{
				throw e;
			}
		}

	}

	private URL validate() throws BuildException {
		if ( this.resource == null || "".equals(this.resource) )
			throw new BuildException("resourceName is a required attribute");
		if ( this.target == null || "".equals(this.target) )
			throw new BuildException("target is a required attribute");
		else
		{
			File file = new File(this.target);
			if ( file.exists() && ! file.canWrite() )
				throw new BuildException("target attribute value must be a writable.");
		}
		try {
			return new URL(this.resource);
		} catch (MalformedURLException e){
			throw new BuildException(e);
		}
	}

	/**
	 * Very small test...
	 * @param args
	 */
	public static void main(String[] args) {
		RadarLoaderTask task = new RadarLoaderTask();
		task.setResource("xradar://resources/tools.xml");
		task.setTarget("target/tools.xml");
		task.execute();
	}

	/**
	 * @return the target
	 */
	public String getTarget() {
		return target;
	}

	/**
	 * @param target the target to set
	 */
	public void setTarget(String target) {
		this.target = target;
	}

}
