/**
 * 
 */
package org.sourceforge.xradar.ant;

import java.util.ArrayList;
import java.util.List;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.sourceforge.xradar.XRadarException;
import org.sourceforge.xradar.results.AnalysingProcess;
import org.sourceforge.xradar.results.Rule;
import org.sourceforge.xradar.results.Violation;
import org.sourceforge.xradar.results.XRadarResultsAnalyserException;

/**
 * 
 * <code>
 * <xradar-analyser failOnError="true|false">
 * 	<rule name="rule1" type="xpath" query="//xpath"/> 
 *  <rule name="rule2" type="xpath" query="//xpath"/>
 *  ...
 * </xradar-analyser>
 * </code>
 * @author Romain PELISSE, belaran@gmail.com
 * 
 * 
 * 
 */
public class ResultsAnalyserTask extends Task {

	private List<Rule> rules;
	private boolean failOnError = false;

	public void addRule(Rule rule)
	{
		if ( this.rules == null )
			this.rules = new ArrayList<Rule>();
		this.rules.add(rule);
	}
	
	public boolean isFailOnError() {
		return failOnError;
	}

	public void setFailOnError(boolean failOnError) {
		this.failOnError = failOnError;
	}

	@Override
	public void execute() throws BuildException {
		validate();
		AnalysingProcess analysingEngine = new AnalysingProcess();
		analysingEngine.setViolations(new ArrayList<Violation>());
		try {
			List<Violation> violations = analysingEngine.analyseResults(rules);
			
			for ( Violation violation : violations ) {
				log(violation.toString());
				if ( failOnError )
					throw new BuildException("XRadar analyser violation:" + violation);
			}
		} catch (XRadarResultsAnalyserException e) {
			throw new BuildException(e);
		} catch (XRadarException e) {
			throw new BuildException(e);
		}
	}

	private void validate() throws BuildException {
		if ( rules == null || rules.size() <= 0 )
			throw new BuildException("at least on nested element 'rule' is required.");
	}
	
	public List<Rule> getRules() {
		return rules;
	}

	public void setRules(List<Rule> rules) {
		this.rules = rules;
	}
}
