/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.config;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;




import java.util.logging.Logger;

import org.sourceforge.xradar.XRadarException;
import org.sourceforge.xradar.util.StreamUtils;

/**
 * <p>Loads all the necessary data (such as Version, Release date...) concerning the Release</p>
 * 
 * @author Romain PELISSE, belaran@gmail.com
 *
 */
public class ReleaseDataLoader {
	
    private static final Logger logger = Logger.getLogger(ReleaseDataLoader.class.getSimpleName());
    private String filename;

    public ReleaseDataLoader() {    	
        super();
    }

    /**
     * @return the filename
     */
    public String getFilename() {
        return filename;
    }

    /**
     * @param filename
     *            the filename to set
     */
    public void setFilename(final String filename) {
        this.filename = filename;
    }

    public ReleaseDataLoader(final String filename) {
        this.setFilename(filename);
    }

    public ReleaseData load() {
        // PropertiesAccessor propertiesAccessor = new PropertiesAccessor(this.filename);
        // create and load default properties
        final ReleaseData release = new ReleaseData();
        try {
            final Properties propertiesAccessor = loadProperties(filename);
            release.setSystem(propertiesAccessor.getProperty("version.label"));
            release.setDate(propertiesAccessor.getProperty("date.label"));
            release.setVersion(propertiesAccessor.getProperty("days.since.last.release"));
            release.setSequencdeId(Integer.valueOf(propertiesAccessor.getProperty("sequence.id")));
        } catch (final XRadarException e) {
            // TODO Don't know if xradar should fail or use default values
            logger.fine("Can't load release properties file" + e.getMessage());
        }
        return release;
    }

    private Properties loadProperties(final String filename)  throws XRadarException {
        notNull(filename, "Missing release properties file");
        final Properties propertiesAccessor = new Properties();
        final File localFile = new File(filename);
        InputStream in;
        // Test if file exists locally
        if (localFile.exists() && localFile.isFile()) {
            try {
                in = new FileInputStream(this.filename);
            } catch (final FileNotFoundException e) {
                throw new XRadarException("Can't find release properties file",e);
            }
        } else {
            // Try to load from classpath
            in = Thread.currentThread().getContextClassLoader().getResourceAsStream(filename);
            if (in == null) {
                throw new XRadarException("Can't find release properties file");
            }
        }
        try {
            propertiesAccessor.load(in);
        } catch (IOException e) {
        	throw new XRadarException("Can't find load data from properties file",e);
		} finally {
			StreamUtils.closeStream(in);
        }
        return propertiesAccessor;
    }
    
    public ReleaseData load(final String filename) {
        // Assign local variable to field before calling load()
        this.filename = filename;
        return this.load();
    }
    
    //TODO: Move to a static lib ?
    public static void notNull(Object object, String message) {
        if (object == null) {
            throw new IllegalArgumentException(message);
        }
    }
}




