/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.resolver;

import java.util.regex.Pattern;

import org.apache.xml.resolver.tools.CatalogResolver;
import org.sourceforge.xradar.util.XRadarUtils;

import javax.xml.transform.Source;
import javax.xml.transform.TransformerException;

/**
* @author pfouquet
* @author Romain PELISSE <belaran@gmail.com>
* 
* <p>Apache CatalogResolver extension to fix a path-related issue on Windows system.</p>
* 
* <p>Such a path D:\temp\test.xml would be converted in file:///D:/temp/test.xml</p>
*/
public class XRadarCatalogResolver extends CatalogResolver {

	private static final String FILE_PROTOCOL = "file:";
	private static final Pattern pattern = Pattern.compile("^[A-Za-z]:.*$");

	public XRadarCatalogResolver() {
		super(false);
	}
	
	/**
	* {@inheritDoc}
	* 
	* <p>Test if the href contains a win32 file path, beginning with a hard drive letter, such as:</p>
	* <code>D:\\path\\to\\file</code>
	* <p>If so, the method will normalize it using XRadarUtils.normalizeFileName method.</p>
	* 
	* @see org.sourceforge.xradar.utils.XRadarUtils#normalizeFileName(java.lang.String)
	* @see org.apache.xml.resolver.tools.CatalogResolver#resolve(java.lang.String,java.lang.String)
	*/
	@Override
	public Source resolve(String href, String base) throws TransformerException {
		String patchedHref = href;
		if ( pattern.matcher(href).matches() ) {
			patchedHref = FILE_PROTOCOL + "//" + XRadarUtils.normalizeFileName(href);
		}
		return super.resolve(patchedHref, base);
	}
}

