/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.statics;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.logging.Level;
import java.util.logging.Logger;

import jdepend.xmlui.JDepend;

import org.sourceforge.xradar.XRadarException;

/**
 * <p>Create the backbone file for xradar. Basicly, an XML file that 
 * depicts the package/classes structure for the project.</p>
 * 
 * <p>For the moment, XRadar depends on JDepend to do this, but
 * at some point we may change this implementation to a custom
 * backbone file.</p>
 * 
 * @author Romain PELISSE, belaran@gmail.com
 * @author Nicolas DORDET,
 *
 */
public class MergeFileBackboneCreator {
	
	/**
	 * <p>check if the classes are presents
	 * if there are in the right directory, run jdepend
	 * if not, exit.</p>
	 * 
	 * @param classDirectory
	 * @throws XRadarException 
	 */
	public static boolean createBackBoneFile(File classes, File reportFile) throws XRadarException 
	{
		Logger logger = Logger.getLogger(MergeFileBackboneCreator.class.getSimpleName());
		boolean status = true;
		if (classes.exists())
		{
			logger.log(Level.INFO,"Supplied directory classes," + classes.getAbsolutePath() + " have been found");
			// using jdepend as an API
			JDepend jdepend = new JDepend();
			try 
			{
				jdepend.addDirectory(classes.getAbsolutePath());	//	jdepend.addDirectory(name) TODO: Explore this 'addDirectory to have a multiproject support ?
				jdepend.setWriter(new PrintWriter( new FileWriter(reportFile)));
			} 
			catch (IOException e) 
			{
				throw new XRadarException("Unable to run JDepend :",e);
			}
			logger.log(Level.INFO,"JDepend Analyze starting ...");
			jdepend.analyze();
		}
		else
		{
			logger.log(Level.INFO,"Classes have not been found in " + classes + ", xradar will not do the audit");
			logger.log(Level.INFO,"make a mvn compile in order to have .class file or change classDirectory parameter");
			status = false;
		}
		return status;
	}
}
