/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.statics;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

/**
 * @author rpelisse
 *
 */
public class MergeProduct
{
		private static final int EOF = -1;
		
		private InputStream radarNormalized;
		private InputStream masterReport;
		private InputStream systemQuality;
		
		private String radarNormalizedFilename;
		private String masterReportFilename;
		private String systemQualityFilename;

		private InputStream rebuildFileInputStream(InputStream stream,String filename) {
			try 
			{
				stream = new FileInputStream(filename);
			} 
			catch (FileNotFoundException fileNotFoundException) 
			{
				// well, this should never happens... :) 
				stream = null;
			}
			return stream;
		}
		
		private InputStream returnStream(InputStream stream,String filename) {
			
					if ( stream.markSupported() ) {
						stream.mark(1);
						try  {
							if ( stream.read() == EOF ) 
							{
								stream = this.rebuildFileInputStream(stream, filename);
							}
							else
							{
								stream.reset();
							}							
						}
						catch (IOException error ) {
							// this should never happens !
							stream = this.rebuildFileInputStream(stream, filename);
						}
					}
					else
					{
						try 
						{
							stream.available(); // throw an exception if stream invalid so ...
						} 
						catch (IOException e) 
						{
							// ... we created again the stream 
							stream = this.rebuildFileInputStream(stream, filename);
						} 
					}
				return stream;
		}
		
		
		/**
		 * @return the radarNormalized
		 */
		public InputStream getRadarNormalized() {
			return this.returnStream(radarNormalized,radarNormalizedFilename);
		}
		/**
		 * @param radarNormalized the radarNormalized to set
		 */
		public void setRadarNormalized(InputStream radarNormalized) {
			this.radarNormalized = radarNormalized;
		}
		/**
		 * @return the masterReport
		 */
		public InputStream getMasterReport() {
			return this.returnStream(masterReport,masterReportFilename);
		}
		/**
		 * @param masterReport the masterReport to set
		 */
		public void setMasterReport(InputStream masterReport) {
			this.masterReport = masterReport;
		}
		/**
		 * @return the systemQuality
		 */
		public InputStream getSystemQuality() {
			return this.returnStream(systemQuality,systemQualityFilename);
		}
		/**
		 * @param systemQuality the systemQuality to set
		 */
		public void setSystemQuality(InputStream systemQuality) {
			this.systemQuality = systemQuality;
		}

		/**
		 * @return the radarNormalizedFilename
		 */
		public String getRadarNormalizedFilename() {
			return radarNormalizedFilename;
		}
		/**
		 * @param radarNormalizedFilename the radarNormalizedFilename to set
		 */
		public void setRadarNormalizedFilename(String radarNormalizedFilename) {
			this.radarNormalizedFilename = radarNormalizedFilename;
		}
		/**
		 * @return the masterReportFilename
		 */
		public String getMasterReportFilename() {
			return masterReportFilename;
		}
		/**
		 * @param masterReportFilename the masterReportFilename to set
		 */
		public void setMasterReportFilename(String masterReportFilename) {
			this.masterReportFilename = masterReportFilename;
		}
		/**
		 * @return the systemQualityFilename
		 */
		public String getSystemQualityFilename() {
			return systemQualityFilename;
		}
		/**
		 * @param systemQualityFilename the systemQualityFilename to set
		 */
		public void setSystemQualityFilename(String systemQualityFilename) {
			this.systemQualityFilename = systemQualityFilename;
		}

}
