/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.statics;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>This class is basic bean designed to contained data
 * describing a Report files coming from PMD, Checkstyle...</p>
 *
 * <p>It basicly contains the filename, the proper xslt to use</p>
 *
 * <p>Use of the other constructor is not compulsory. One
 *  may want to create an empty instance and then
 * set it using the appropriate getter/setters.</p>
 * 
 * @author rpelisse, belaran@gmail.com
 *
 */
public class Report implements Comparable<Report>
{
	private String file;
	private String mergingFile;
	private String type;
	private int orderId;
	private Map<String,Param> params = new HashMap<String,Param>(0);

	public Report(){
		// Ant need this empty constructor, and as there is an other one,
		// this will not be generated by the compiler.
	}
	/**
	 * <p>In order to identify a report, it is handy to be able to construct
	 * a report instance with only the orderId.</p>
	 * 
	 * @param orderId, the appropriate orderId.
	*/
	public Report(int orderId) {
		this.orderId = orderId;
	}
	
	/** 
	 * <p>Most common constructor for a report.</p>
	 * <p>Includes a type for the report, and a filename.</p>
	 * 
	 * @param type
	 * @param file
	 */
	public Report(String type, String file) {
		this.type = type;
		this.file = file;
	}

	/**
	 * <p>Basic overides of toString. FIXME: Enhance to output the params.</p>
	 */
	@Override
	public String toString() {
		return "File : " + this.file + ", merging into : " + this.mergingFile + "[orderId:" + this.orderId + ",type:" + this.type + "]";
	}
	
	/**
	 * @return the filename
	 */
	public String getFile() {
		return file;
	}
	/**
	 * @param filename the filename to set
	 */
	public void setFile(String filename) {
		this.file = filename;
	}
	/**
	 * @return the mergingFile
	 */
	public String getMergingFile() {
		return mergingFile;
	}
	/**
	 * @param mergingFile the mergingFile to set
	 */
	public void setMergingFile(String mergingFile) {
		this.mergingFile = mergingFile;
	}
	/**
	 * @return the orderId
	 */
	public int getOrderId() {
		return orderId;
	}
	/**
	 * @param orderId the orderId to set
	 */
	public void setOrderId(int orderId) {
		this.orderId = orderId;
	}

	/**
	 * Report are compared solely on their order id
	 */
	public int compareTo(Report o) {
		if ( this.getOrderId() > o.getOrderId() ){
			return 1;
		}
		else if ( this.getOrderId() < o.getOrderId() ){
			return -1;
		}
		return 0;
	}

	/**
	 * Report are considered equals if the have the same orderId.
	 * This ensures consistent checking of the order id.
	 */
	@Override
	public boolean equals(Object o)
	{
		boolean result = false;
		if ( o instanceof Report ) {
			Report otherReport = (Report)o;
			if ( this.getOrderId() == otherReport.getOrderId() )
				result = true;
		}
		return result;
	}
	/**
	 * @return the params
	 */
	public Map<String,Param> getParams() {
		return params;
	}
	/**
	 * @param params the params to set
	 */
	public void setParams(Map<String,Param> params) {
		this.params = params;
	}
	/**
	 * @return the type
	 */
	public String getType() {
		return type;
	}
	/**
	 * @param type the type to set
	 */
	public void setType(String type) {
		this.type = type;
	}

}
