/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.statics.renderers;

import java.io.IOException;
import java.io.InputStream;
import java.io.StringWriter;
import java.util.List;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFactory;

import org.sourceforge.xradar.DefaultReportValues;
import org.sourceforge.xradar.XRadarException;
import org.sourceforge.xradar.results.XPathQueryAnalyser;
import org.sourceforge.xradar.statics.MergeProduct;
import org.sourceforge.xradar.statics.Param;
import org.sourceforge.xradar.statics.Preambule;
import org.sourceforge.xradar.statics.Statics;
import org.sourceforge.xradar.util.StreamUtils;
import org.sourceforge.xradar.util.XMLUtils;
import org.sourceforge.xradar.util.XRadarUtils;
import org.w3c.dom.Node;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * @author Romain PELISSE <belaran@gmail.com>
 *
 */
public class XslHtmlWebsite extends Statics {

	private Logger logger = Logger.getLogger(XslHtmlWebsite.class.getName());

	private Map<String, Param> params;

	private static final String MASTER_REPORT_DETAIL = DefaultReportValues.getString("radar.internal.master.report.detail");
	private static final String MASTER_REPORT_XML_PLUGIN = DefaultReportValues.getString("radar.internal.master.report.xml.plugin");
	private static final String GENERATE_STATICS_SVG = DefaultReportValues.getString("radar.internal.generate.statics.svgs");
	private static final String GENERATE_DUPLICATION_GRAPH = DefaultReportValues.getString("radar.internal.graph.duplication");
	private static final String GENERATE_COUPLING_GRAPH = DefaultReportValues.getString("radar.internal.graph.coupling");
	private static final String GENERATE_PACKAGE_GRAPH = DefaultReportValues.getString("radar.internal.graph.package");
	private static final String GENERATE_MODULE_GRAPH = DefaultReportValues.getString("radar.internal.graph.modules");
	private static final String GENERATE_STATICS_OLD_STYLE_SVG = DefaultReportValues.getString("radar.internal.generate.statics.old.style.svgs");


	/**
	 * Generate final statics website for XRadar.
	 * @param products
	 * @param params
	 * @return
	 * @throws XRadarException 
	 */
	public String generateHtmlReport(MergeProduct products,Map<String,Param> params) throws XRadarException
	{
		logger.log(Level.FINE,"Params are:" + params.toString());
		this.params = params;
		// Adding generic parameters
		Preambule preambule = new Preambule();
		preambule.setParams(params);
		if (XRadarUtils.isRunningOnWindowsOS())
			preambule.getParams().put(DOCS_HOME,new Param(DOCS_HOME, SYSTEM_FILE_SEPARATOR + this.getDocsHome()));
		else
			preambule.getParams().put(DOCS_HOME,new Param(DOCS_HOME,this.getDocsHome()));
		// Adding variable parameters
		if ( ! params.containsKey("log") )
			addLogLevelDefinitionToPreambule(preambule);
		// If we run unit test, we may the according view on the website
		preambule.getParams().put(TEST_ENABLED,new Param(TEST_ENABLED,String.valueOf(this.isUnitTestAvailaible())));
		logger.log(Level.FINE,"Test enabled:" + this.isUnitTestAvailaible());
		logger.log(Level.FINE,"Configuration file:" + params.get(XRADAR_CONFIG_FILE));
		logger.log(Level.FINE,"Docs home:" + this.getDocsHome());

		logger.log(Level.FINEST,"XML input is (MasterReport) \n" + products.getMasterReport());
		logger.log(Level.FINE,"Processing radar normalized with " + MASTER_REPORT_DETAIL);

		merger.setXmlResult(StreamUtils.createOuput(new StringWriter()));
		// Generate website
		StreamUtils.closeStream(processStep(new InputSource(products.getMasterReport()),MASTER_REPORT_DETAIL,preambule,this.getDocsHome() + SYSTEM_FILE_SEPARATOR +  "generating-website.xml"));
		// generate_plugin_api
		generateGraph(products.getRadarNormalized(),MASTER_REPORT_XML_PLUGIN,"Master XML plugin",preambule,this.getDocsHome()  + SYSTEM_FILE_SEPARATOR + "master-xml-plugin.xml");
		// generate_statics_svgs
		generateGraph(products.getRadarNormalized(),GENERATE_STATICS_SVG,"Generating statics svg",preambule,this.getDocsHome()  + SYSTEM_FILE_SEPARATOR + "statics-svg.xml");
		// duplication graphics
		generateGraph(products.getRadarNormalized(),GENERATE_DUPLICATION_GRAPH,"Generating duplication graphics",preambule,this.getDocsHome()  + SYSTEM_FILE_SEPARATOR + "duplication-graphics.xml");
		// Coupling graphics generation
		generateGraph(products.getRadarNormalized(),GENERATE_COUPLING_GRAPH,"Generating coupling graphics",preambule,this.getDocsHome()  + SYSTEM_FILE_SEPARATOR + "coupling-graphics.xml");
		// Package graphics generation
		generateGraph(products.getRadarNormalized(),GENERATE_PACKAGE_GRAPH,"Generating package graphics",preambule,this.getDocsHome()  + SYSTEM_FILE_SEPARATOR + "package-graphics.xml");
		// Module graphics generation
		generateGraph(products.getRadarNormalized(),GENERATE_MODULE_GRAPH,"Generating module graphics",preambule,this.getDocsHome()  + SYSTEM_FILE_SEPARATOR + "module-graphics.xml");
		// generate_statics_svgs (old style)
		// TODO: Replace the distance graph from 'old style' by the new one !
		generateGraph(products.getMasterReport(),GENERATE_STATICS_OLD_STYLE_SVG,"Generating statics svg (old style)",preambule,this.getDocsHome()  + SYSTEM_FILE_SEPARATOR + "statics-svg.xml");
		// Customizing website
		return "";
	}

	@Override
	public void copyStaticResourcesToWebSite(String imagesTargetPrefix,String xmlDataPrefix) throws XRadarException {
		super.copyStaticResourcesToWebSite(imagesTargetPrefix,xmlDataPrefix);
		this.customizeLogo(params.get(XRADAR_CONFIG_FILE).getExpression());
	}
	
	/*
	 * FIXME: Find a better way than tweak XPathAnalyser into this...
	 */
	private void customizeLogo(String radarConfigFile) throws XRadarException {
		logger.finer("called with " + radarConfigFile);
		XPathQueryAnalyser xpathAnalyser = new XPathQueryAnalyser();
		xpathAnalyser.setInputStream(StreamUtils.readFile(radarConfigFile));
		xpathAnalyser.setXpath(XPathFactory.newInstance().newXPath());
		xpathAnalyser.setBuilder(XMLUtils.getDocumentBuilder());
		logger.finer("analyser built");
		try {
			List<Node> nodes = xpathAnalyser.executeXPathQuery(xpathAnalyser.getBuilder().parse(xpathAnalyser.getInputStream()), "//website/logo");
			for ( Node node : nodes ) {
				String path = node.getAttributes().getNamedItem("path").getNodeValue();
				if ( path != null && ! "".equals(path) ) {
					String target = this.getDocsHome() + SYSTEM_FILE_SEPARATOR + DefaultReportValues.getString("radar.internal.static.resources.target.4") ;
					logger.finer("Custom logo find with path " + path);
					StreamUtils.copyFileToFile(path, target);					
				}
			}
		} catch (XPathExpressionException e) {
			throw new XRadarException(e);
		} catch (SAXException e) {
			throw new XRadarException(e);
		} catch (IOException e) {
			throw new XRadarException(e);
		}
		logger.finer("works done");
	}



	/*
	 * Commodity method to generate svg ( and log data )
	 * @param inputXml
	 * @param stylesheet
	 * @param logMssg
	 * @param preambule
	 */
	private void generateGraph(InputStream inputXml,String stylesheet,String logMssg,Preambule preambule,String outputFilename) throws XRadarException
	{
		logger.log(Level.INFO,logMssg);
		logger.log(Level.FINE,"Processing radar normalized with " + stylesheet);
		logger.log(Level.FINEST,"XML input is \n" + inputXml + "\n");
		StreamUtils.closeStream(processStep(new InputSource(inputXml),stylesheet,preambule,outputFilename));
	}
}
