/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.util;

import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;

import org.sourceforge.xradar.XRadarException;

/**
 * @author Romain PELISSE <belaran@gmail.com>
 *
 */
public final class URLUtils {

	/**
	 * <p>Handy method to create an {@link URLConnection} instance that
	 * wraps any exception in an {@link XRadarException}.</p>
	 * 
	 * @param urlAsString
	 * @return the {@link URLConnection} instance or <code>null</code>.
	 * @throws XRadarException
	 */
	public static URLConnection openConnection(String urlAsString) throws XRadarException {
		try {
			return URLUtils.createURL(urlAsString).openConnection();
		} catch (IOException e) {
			throw new XRadarException(e);
		}
	}
	
	/**
	 * <p>Handy method to create an {@link URL} that wraps any exception
	 * in an {@link XRadarException}.
	 * 
	 * @param url, a {@link String} that describs the URL.
	 * @return the {@link URL} instance or <code>null</code>.
	 * @throws XRadarException 
	 */
	public static URL createURL(String url) throws XRadarException {
		try
		{
			return new URL(url);
		}
		catch (MalformedURLException e)
		{
			throw new XRadarException(e);
		}
	}
	
	/**
	 * <p>An handy method that create an {@link InputStream} and that wraps
	 * any exception in an {@link XRadarException} instance.</p>
	 * 
	 * @param url, a {@link String} that describs the URL.
	 * @return the {@link InputStream} instance of <code>null</code>.
	 * @throws XRadarException
	 */
	public static InputStream openStream(String url) throws XRadarException {
		try {
			return URLUtils.createURL(url).openStream();
		} catch (IOException e) {
			throw new XRadarException(e);
		}
	}
}
