/**
 * BSD-style license; for more info see http://xradar.sourceforge.net/license.html
 */
package org.sourceforge.xradar.util;

import java.util.logging.Logger;

import org.sourceforge.xradar.statics.Report;

/**
 * @author Romain PELISSE, belaran@gmail.com
 */
public final class XRadarUtils {

	private static boolean isRunningOnWindows;

	// should not be instantiated
	private XRadarUtils(){}

	/**
	 * On windows, some filename may have both '\' and '/' resulting to some
	 * bad concatenation. This method fixes the issues.
	 *
	 * @param filename
	 * @return
	 */
	public static String normalizeFileName(String file) {
		Logger logger = Logger.getLogger(XRadarUtils.class.getSimpleName());
		logger.finest("Entering normalize filename with" + file);
		XRadarUtils.isRunningOnWindows = XRadarUtils.isRunningOnWindowsOS();
		if ( isRunningOnWindows && file.contains("\\") ) //!&& file.contains("/") )
		{
			logger.finest("Normalizing filename:" + file);
			// We replace only the '\\' by '/'
			file = file.replace('\\', '/');
			//			// If this is an absolute path, we remove the drive
			//			Pattern pattern = Pattern.compile("^[A-Za-z]:.*$");
			//			if ( pattern.matcher(file).matches() )
			//			{
			//				file = file.substring(2,file.length());
			//				logger.finest("Normalized to:" + file);
			//			}
			//			else
			//				logger.finest("Normalizing failed for:" + file);
			//
		}
		return file;
	}

	/**
	 * <p>Handy method to see if xradar is running on Windows or one real OS.</p>
	 * 
	 * @return
	 */
	public static boolean isRunningOnWindowsOS()
	{
		boolean status = false;
		String[] windows = { "Windows 98", "Windows ME", "Windows 2000", "Windows XP", "Windows Vista", "Windows 2003", "Windows 7" };

		int idWindows;
		String os = System.getProperty("os.name");
		if (os != null )
			for ( idWindows = 0; idWindows < windows.length; idWindows++ )
				if ( os.startsWith(windows[idWindows]) )
					status = true;

		return status;
	}

	public static String removeDiskNameIfRunningOnWindows(String filename) {
		String result = filename;
		if ( XRadarUtils.isRunningOnWindowsOS()) {
			result = filename.replaceFirst("^[A-Za-z]:", "");
		}
		return result;
	}
	
}
